@@ -1,7 +1,7 @@
 /*
 **  OSSP uuid - Universally Unique Identifier
-**  Copyright (c) 2004-2005 Ralf S. Engelschall <rse@engelschall.com>
-**  Copyright (c) 2004-2005 The OSSP Project <http://www.ossp.org/>
+**  Copyright (c) 2004-2006 Ralf S. Engelschall <rse@engelschall.com>
+**  Copyright (c) 2004-2006 The OSSP Project <http://www.ossp.org/>
 **
 **  This file is part of OSSP uuid, a library for the generation
 **  of UUIDs which can found at http://www.ossp.org/pkg/lib/uuid/
@@ -30,6 +30,16 @@
 #ifndef __UUID_H__
 #define __UUID_H__
 
+/* workaround conflicts with system headers */
+#define uuid_t       __vendor_uuid_t
+#define uuid_create  __vendor_uuid_create
+#define uuid_compare __vendor_uuid_compare
+#include <sys/types.h>
+#include <unistd.h>
+#undef  uuid_t
+#undef  uuid_create
+#undef  uuid_compare
+
 /* required system headers */
 #include <string.h>
 
@@ -45,11 +55,12 @@
 DECLARATION_BEGIN
 
 /* OSSP uuid version (compile-time information) */
-#define UUID_VERSION  0x103202
+#define UUID_VERSION  0x105200
 
 /* encoding octet stream lengths */
 #define UUID_LEN_BIN  (128 /*bit*/ / 8 /*bytes*/)
 #define UUID_LEN_STR  (128 /*bit*/ / 4 /*nibbles*/ + 4 /*hyphens*/)
+#define UUID_LEN_SIV  (39  /*int(log(10,exp(2,128)-1)+1) digits*/)
 
 /* API return codes */
 typedef enum {
@@ -74,7 +85,8 @@ enum {
 typedef enum {
     UUID_FMT_BIN = 0,        /* binary representation (import/export) */
     UUID_FMT_STR = 1,        /* string representation (import/export) */
-    UUID_FMT_TXT = 2         /* textual description   (export only)   */
+    UUID_FMT_SIV = 2,        /* single integer value  (import/export) */
+    UUID_FMT_TXT = 3         /* textual description   (export only)   */
 } uuid_fmt_t;
 
 /* UUID abstract data type */
